==> jc-1.4.0.tar.gz: gnu/java/nio/charset/ISO__5f8859__5f1__24Encoder.h <==
// final class gnu.java.nio.charset.ISO_8859_1$Encoder

// class file dependencies
// @dep_class a91e4232442d4b03 gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 702d6146848c5569 java_nio_charset_CharsetEncoder

// header file dependencies
// @dep_header java_nio_charset_CharsetEncoder

#include "java/nio/charset/CharsetEncoder.h"

#ifndef _JC_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder_H_
#define _JC_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_ByteBuffer$object;
struct _jc_java_nio_CharBuffer$object;
struct _jc_java_nio_charset_Charset$object;
struct _jc_java_nio_charset_CoderResult$object;

// Typedefs
typedef struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$sub_refs	_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$sub_refs;
typedef struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$sub_nonrefs	_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$sub_nonrefs;
typedef struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$refs	_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$refs;
typedef struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$nonrefs	_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$nonrefs;
typedef struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$object	_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$object;

typedef const struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$vmethods	_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$vmethods;
typedef const struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$vtable	_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$vtable;
typedef const struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$vtype	_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$vtype;

// Constructors
extern void _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$method$_init$a3cee2967eb85389(_jc_env *, struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$object *, struct _jc_java_nio_charset_Charset$object *);

// Virtual methods
extern struct _jc_java_nio_charset_CoderResult$object *_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$method$encodeLoop$2ce0cadadd176638(_jc_env *, struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$object *, struct _jc_java_nio_CharBuffer$object *, struct _jc_java_nio_ByteBuffer$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$method_info$encodeLoop$2ce0cadadd176638;

// Virtual methods structure
struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$vmethods {
	struct _jc_java_nio_charset_CoderResult$object	*(*encodeLoop$2ce0cadadd176638)(_jc_env *, struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$object *, struct _jc_java_nio_CharBuffer$object *, struct _jc_java_nio_ByteBuffer$object *);
};

// Vtable
struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_charset_CharsetEncoder$vmethods	java_nio_charset_CharsetEncoder;
	_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$vmethods	gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder;
};

// Vtype
struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$refs {
    _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$sub_refs	gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder;
    _jc_java_nio_charset_CharsetEncoder$sub_refs	java_nio_charset_CharsetEncoder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_charset_CharsetEncoder$sub_nonrefs	java_nio_charset_CharsetEncoder;
    _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$sub_nonrefs	gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder;
};

// Object instance structure
struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$object {
	_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$vtype	*vtype;
	_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$vtype _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$class_object;

#endif	/* _JC_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder_H_ */

==> jc-1.4.6.tar.gz: gnu/java/nio/charset/ISO__5f8859__5f1__24Encoder.h <==
// final class gnu.java.nio.charset.ISO_8859_1$Encoder

// class file dependencies
// @dep_class a91e4232442d4b03 gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 50801be894e42472 java_nio_charset_CharsetEncoder

// header file dependencies
// @dep_header java_nio_charset_CharsetEncoder

#include "java/nio/charset/CharsetEncoder.h"

#ifndef _JC_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder_H_
#define _JC_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_ByteBuffer$object;
struct _jc_java_nio_CharBuffer$object;
struct _jc_java_nio_charset_Charset$object;
struct _jc_java_nio_charset_CoderResult$object;

// Typedefs
typedef struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$sub_refs	_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$sub_refs;
typedef struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$sub_nonrefs	_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$sub_nonrefs;
typedef struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$refs	_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$refs;
typedef struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$nonrefs	_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$nonrefs;
typedef struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$object	_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$object;

typedef const struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$vmethods	_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$vmethods;
typedef const struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$vtable	_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$vtable;
typedef const struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$vtype	_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$vtype;

// Constructors
extern void _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$method$_init$a3cee2967eb85389(_jc_env *, struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$object *, struct _jc_java_nio_charset_Charset$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_nio_charset_CoderResult$object *_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$method$encodeLoop$2ce0cadadd176638(_jc_env *, struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$object *, struct _jc_java_nio_CharBuffer$object *, struct _jc_java_nio_ByteBuffer$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$method_info$encodeLoop$2ce0cadadd176638;

// Virtual methods structure
struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$vmethods {
	struct _jc_java_nio_charset_CoderResult$object	*(*encodeLoop$2ce0cadadd176638)(_jc_env *, struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$object *, struct _jc_java_nio_CharBuffer$object *, struct _jc_java_nio_ByteBuffer$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_charset_CharsetEncoder$vmethods	java_nio_charset_CharsetEncoder;
	_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$vmethods	gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder;
};

// Vtype
struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$refs {
    _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$sub_refs	gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder;
    _jc_java_nio_charset_CharsetEncoder$sub_refs	java_nio_charset_CharsetEncoder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_charset_CharsetEncoder$sub_nonrefs	java_nio_charset_CharsetEncoder;
    _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$sub_nonrefs	gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder;
};

// Object instance structure
struct _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$object {
	_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$vtype	*vtype;
	_jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$vtype _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder$class_object;

#endif	/* _JC_gnu_java_nio_charset_ISO__5f8859__5f1__24Encoder_H_ */
